%% Basic FIR Filter Box
%
% This example demonstrates how to run the FIR Filter Box and configure its
% individual filter channel coefficients.
%
% NOTE: This example requires installation of the MATLAB Signal Processing 
%       Toolbox to generate filter coefficients. The MokuIIRFilterBox can 
%       be used directly with pre-defined coefficients.
%
% (c) 2017 Liquid Instruments Pty. Ltd.
%

% The following two example arrays are simple rectangular FIR kernels with 50
% and 400 taps respectively. A rectangular kernel produces a sinc shaped
% transfer function with width inversely proportional to the length of the
% kernel. FIR kernels must have a normalised power of <= 1.0, so the value of
% each tap is the inverse of the total number of taps.
filt_coeff1 = zeros(1, 50);
filt_coeff1(:) = 1.0/50;
filt_coeff2 = zeros(1, 400);
filt_coeff2(:) = 1.0/400;

%% Connect to your Moku
ip = input('Please enter your Moku:Lab IP address: ', 's');

% Connect to your Moku and deploy the desired instrument
m = MokuFIRFilter(ip);

%% Configure the instrument
m.set_frontend(1, 'fiftyr', 'true', 'atten', 'false', 'ac', 'false');
m.set_frontend(2, 'fiftyr', 'true', 'atten', 'false', 'ac', 'false');

% Load the coefficients for each FIR filter channel.
%
% The channel's decimation factor determines the filter sample rate (Fs) and
% the maximum number of filter kernel coefficients (N) for the channel.
% The defining equations are given by:
%
%   3 <= decimation_factor <= 10,
% 	Fs = 125 MHz / 2^decimation_factor,
% 	N  = 2^(decimation_factor) * 29.

% To implement 50 FIR taps, N = 2^(3) * 29 = 232 > 50
m.set_filter(1, 3, filt_coeff1); % ~15.625 Smp/s

% To implement 400 FIR taps, N = 2^(4) * 29 = 464 > 400
m.set_filter(2, 4, filt_coeff2);  % ~122 Smp/s

% Both channels have unity gain and no offsets
m.set_gains_offsets(1, 'input_gain', 1.0, 'output_gain', 1.0, 'input_offset', 0, 'output_offset', 0)
m.set_gains_offsets(2, 'input_gain', 1.0, 'output_gain', 1.0, 'input_offset', 0, 'output_offset', 0)

